//
// JTypist v3.1 - Java typing tutor program for UNIX systems
// Copyright (C) 2000  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// Lesson class - defines the contents of a basic lesson class
//
import java.util.ResourceBundle;
import java.util.MissingResourceException;
import java.text.MessageFormat;

/**
 * Defines the contents of a basic lesson class.
 */
public abstract class Lesson {

	// message catalog information
	private static ResourceBundle	messages	=
				ResourceBundle.getBundle( "MessageResource" );

	// information held about an individual lesson
	private String		series_id;	// owner lesson series ID
	private ResourceBundle	resource;	// property resource bundle
	private String		name;		// lesson name, for properties
	private String		title;		// lesson title string
	private String		text;		// text the lesson delivers


	/**
	 * Lesson constructor.
	 *
	 * Deprecated as of version 3.1h.
	 */
	public Lesson( String title, String text ) {
		this.title	= title;
		this.text	= text;
	}

	/**
	 * Lesson constructor.
	 */
	public Lesson( String series_id, ResourceBundle resource,
			String name ) {
		this.series_id	= series_id;
		this.resource	= resource;
		this.name	= name;
	}


	/**
	 * Retrieve a lesson attribute from the resources.
	 */
	protected String get_attribute( String attribute ) {

		// try to retrieve the attribute
		try {
			return ( resource.getString( name + "." + attribute ));
		}
		catch ( MissingResourceException e ) {
			return ( null );
		}
	}


	/*
	 * Accessor methods.
	 */
	public String get_title() {

		// return the title if we have it already
		if ( title != null )
			return ( title );

		// get the lesson title string, and default if still null
		title = get_attribute( "title" );
		if ( title == null ) {
			title = messages.getString( "Lesson.untitled" );
			String[] fmtargs = { series_id, name };
			System.err.println( MessageFormat.format(
					messages.getString(
					"Lesson.missingtitle" ),
								fmtargs ));
		}
		return ( title );
	}
	public String get_text() {

		// return the text if we have it already
		if ( text != null )
			return ( text );

		// get the lesson text string, and default if still null
		text = get_attribute( "text" );
		if ( text == null ) {
			text = "";
			String[] fmtargs = { series_id, name };
			System.err.println( MessageFormat.format(
					messages.getString(
					"Lesson.missingtext" ),
								fmtargs ));
		}
		return ( text );
	}


	/**
	 * Printout method.
	 */
	public String toString() {
		return ( getClass().getName() + "{title=\"" + get_title()
				+ "\",text=\"" + get_text() + "\"}" );
	}
}
